package com.notificationFramework.sedentary.frontEnd;

import android.content.Context;
import android.content.SharedPreferences;
import android.os.Environment;
import android.util.Log;

import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * Created by Peter De Jonckheere on 12/02/2018.
 */

public class SaveFile {

    private static void recordTimeStamp(int sent, int clicked, int acknowledged, Context context) {
        Calendar cal = Calendar.getInstance();
        ArrayList<String> contents = new ArrayList<String>();
        String line = "";
        if (isExternalStorageMounted()) {
            File dir = getDirectory(context);
            File file = new File(dir, "TIMESTAMPLOG");
            if (!file.exists()) {
                try {
                    file.createNewFile();
                } catch (IOException e) {
                    Log.e("FILE_ERROR", "COULDN'T CREATE NEW FILE");
                }
            }
            try {
                if (file.isFile() && file.canRead()) {
                    BufferedReader br = new BufferedReader(new FileReader(file));
                    while ((line = br.readLine()) != null) {
                        contents.add(line + '\n');
                    }
                }
                if (file.isFile() & file.canWrite()) {
                    BufferedWriter bw = new BufferedWriter(new FileWriter(file));
                    if (contents.size() > 999) {
                        contents.remove(0);
                    }
                    for (String ts : contents) {
                        bw.write(ts);
                    }
                    bw.write(cal.getTime().toString() + " "+ sent + "" + clicked);
                    bw.close();
                }

            } catch (IOException e) {
                Log.e("FILEERROR", "COULD NOT WRITE TO FILE");
            }
        }
    }

    public static void recordNotification(int sent, int clicked, int acknowledged, Context context) {
        int ns = 0;
        int nc = 0;
        int na = 0;
        if (isExternalStorageMounted()) {
            File dir = getDirectory(context);
            if (dir.isDirectory()) {
                File file = new File(dir, "NOTLOG");
                try {
                    if(!file.exists()) {
                        file.createNewFile();
                    }
                    if (file.isFile() & file.canRead()) {
                        BufferedReader br = new BufferedReader(new FileReader(file));
                        try {
                            ns = Integer.parseInt(br.readLine());
                            nc = Integer.parseInt(br.readLine());
                            na = Integer.parseInt(br.readLine());
                        }catch(NumberFormatException e){

                        }
                        if (file.isFile() & file.canWrite()) {
                            BufferedWriter bw = new BufferedWriter(new FileWriter(file));
                            ns += sent;
                            nc += clicked;
                            na += acknowledged;
                            bw.write(String.valueOf(ns));
                            bw.newLine();
                            bw.write(String.valueOf(nc));
                            bw.newLine();
                            bw.write(String.valueOf(na));
                            bw.close();
                        }
                    }
                }catch (IOException e) {
                    }
            }
        }
        recordTimeStamp(sent, clicked, acknowledged, context);
    }

    public static File zipFiles(Context context) {
        File file = null;
        if (isExternalStorageMounted()) {
            File dir = getDirectory(context);
            if (dir.isDirectory()) {
                file = new File(dir, "ZIPFILE.zip");
                try {
                    if (!file.exists()) {
                        file.createNewFile();
                    }
                    FileOutputStream fos = new FileOutputStream(file);
                    ZipOutputStream zos = new ZipOutputStream(new BufferedOutputStream(fos));
                    File[] files = dir.listFiles();
                    try {
                        for(int i = 0; i < files.length; i++){
                            byte[] buffer = new byte[1024];
                            FileInputStream fis = new FileInputStream(files[i]);
                            zos.putNextEntry(new ZipEntry(files[i].getName()));
                            int length;
                            while ((length = fis.read(buffer)) > 0) {
                                zos.write(buffer, 0, length);
                            }
                            zos.closeEntry();
                            fis.close();
                        }
                    }
                    finally {
                        zos.close();
                    }

                } catch (IOException e) {

                }
            }
        }
        return file;
    }
    public static void recordNotificationType(Context context) {
        SharedPreferences shared = context.getSharedPreferences(context.getString(R.string.preference_file_key), Context.MODE_PRIVATE);
        int sound = 0;
        int led = 0;
        int vibration = 0;

        if (isExternalStorageMounted()) {
            File dir = getDirectory(context);
            if (dir.isDirectory()) {
                File file = new File(dir, "TYPELOG");
                try {
                    if(!file.exists()) {
                        file.createNewFile();
                    }
                if (file.isFile() & file.canRead()) {

                        BufferedReader br = new BufferedReader(new FileReader(file));
                        try {
                            sound = Integer.parseInt(br.readLine());
                            led = Integer.parseInt(br.readLine());
                            vibration = Integer.parseInt(br.readLine());
                        }catch (NumberFormatException e){

                        }
                        if (file.isFile() & file.canWrite()) {
                            BufferedWriter bw = new BufferedWriter(new FileWriter(file));
                            if(shared.getBoolean(context.getString(R.string.audio), false)) {
                                sound++;
                            }
                            if(shared.getBoolean(context.getString(R.string.led), false)){
                                led++;
                            }
                            if(shared.getBoolean(context.getString(R.string.vibration), false)) {
                                vibration++;
                            }
                            bw.write(sound);
                            bw.newLine();
                            bw.write(led);
                            bw.newLine();
                            bw.write(vibration);
                        }
                    }
                } catch (IOException e) {

                    }
                }
            }
        }

    /* Checks if external storage is available */
    private static boolean isExternalStorageMounted() {
        return (Environment.MEDIA_MOUNTED.equals(Environment.getExternalStorageState()));

    }



    private static File getDirectory(Context context) {
        File file = new File(context.getExternalFilesDir(
                Environment.DIRECTORY_DOCUMENTS), "NOTLOGS");
        if (!file.exists()){
            if (!file.mkdirs()) {
                Log.e("DIRERROR", "Directory not created");
            }
    }
        return file;
    }

}